instrumenttools.AltoSaxophone
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone

.. autoclass:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__repr__
   :noindex:
